@@ -12,7 +12,7 @@ from ..core.sensor import UARTSensor
 from ..core.error import Error
 import timeout_decorator
 
-logging.basicConfig(level=logging.INFO)
+# logging.basicConfig(level=logging.INFO)
 
 
 class SPS30(UARTSensor):
